@@ -3,16 +3,18 @@ use strict;
 use warnings;
 use Carp qw();
 
-our $VERSION = '0.10';
+our $VERSION = '0.11';
 
 use Package::Autoloader::Package;
 my $PACKAGES = {};
 
 my $obtain = sub {
 	my ($pkg_name, $visit_point) = @_;
-	unless (exists($PACKAGES->{$pkg_name})) {
-		$PACKAGES->{$pkg_name} = Package::Autoloader::Package->new
-			($pkg_name, $visit_point);
+	if (exists($PACKAGES->{$pkg_name})) {
+		$PACKAGES->{$pkg_name}->set_visit_point($visit_point);
+	} else {
+		$PACKAGES->{$pkg_name} = Package::Autoloader::Package
+			->new($pkg_name, $visit_point);
 	}
 	return($PACKAGES->{$pkg_name});
 };
@@ -39,30 +41,19 @@ sub import {
 	my ($class) = (shift);
 
 	return unless (exists($_[0]));
-	if (ref($_[0]) ne 'CODE') {
-		Carp::confess("Don't know what to do with '$_[0]'.\n");
-	}
-	my $visit_point = shift;
-
-	my $pkg = $obtain->((caller)[0], $visit_point);
-	foreach my $arg (@_) {
-		if (ref($arg) eq 'CODE') {
-			$arg->($pkg);
-			next;
+	my $pkg = $obtain->((caller)[0], shift);
+	if (exists($_[0])) {
+		if (ref($_[0]) ne 'CODE') {
+			Carp::confess("Don't know what to do with '$_[0]'.\n");
 		}
+		$_[0]->($pkg);
 	}
 	return;
 }
 
-sub again {
-	my $pkg = $obtain->((caller)[0], undef);
-	$pkg->set_visit_point(shift);
-	return(shift->($pkg));
-}
-
 #sub debug_dump {
 #	use Data::Dumper;
 #	print STDERR Dumper($PACKAGES);
 #}
 
-1;
+1;
\ No newline at end of file
