@@ -13,10 +13,10 @@ sub new {
 
                 my $sub_body = sprintf(
 			qq{print 'Hello %s\n'},
-			substr($sub_name, 6));
+			substr($sub_name, 6) || '');
  		return($sub_body);
         };
 	bless($generator, $class);
 }
 
-1;
+1;
\ No newline at end of file
